Pulselab contains:
    Class Pulse : This defines a single pulse. It is defined in terms of pulse descriptor parameters (e.g. Pulse width). It also has a, created, waveform and timebase.
    Class Pulses : This holds a number of pulses. It has a generated waveform that holds all the pulse.
     